# Active Backlog

This page lists the backlog from oplog owners.
If you have a feature request, please open an issue, as described in [Contribution](contribution.md).

## Investigate

1. Timeouts (async only or for sync as well?)
    - https://stackoverflow.com/questions/45426713/how-to-gracefully-timeout-with-asyncio
    - https://stackoverflow.com/questions/492519/timeout-on-a-function-call
2. Revisit the timing mechanism (performance timer vs clock timer)
3. Support custom inheritors

### Docs

1. Top navigation to use sections, Side navigations to show pages within a section - like in https://squidfunk.github.io/mkdocs-material/getting-started/
2. Getting Started
3. Refer to FastAPI for docs
4. API reference
5. Sections and ordering of the pages
6. Compare logbook to oplog

## Aesthetics

2. add git repo
[docs](https://squidfunk.github.io/mkdocs-material/setup/adding-a-git-repository/#adding-a-git-repository)

3. publish to github pages [video](https://youtu.be/Q-YA_dA8C20?t=839)
